==> flutter_yim-1.0.3.tar.gz: lib/model/YIMModel.dart <==
part of YIM;

class _YIMSDK {
  static YIMOption? option;
  static String? currentUser;
  static final db = _YIMDB();
  static final server = _YIMServer();
  static final utils = _YIMUtils();
  static final config = _YIMConfig();
}

class YIMOption {
  YIMOption({required this.appKey});

  String appKey;
}

class _YIMResult<T> {
  _YIMResult({required this.code, required this.msg});

  T code;
  String msg;
}

/**
 * 消息体
 */
class YIMMessage {
  YIMMessage();

  String id = "";
  String content = "";
  String from = "";
  String to = "";
  late YIMEnum_ConversationType conversationType;
  late YIMEnum_MessageType messageType;
  late YIMEnum_MessageState messageState;
  late DateTime time;
  String localExt = "";
  bool isRevoke = false;

  YIMMessage.fromJson(Map<String, dynamic> map) {
    id = map["id"]?.toString() ?? "";
    content = Uri.decodeComponent(map["content"]?.toString() ?? "");
    from = map["from"]?.toString() ?? "";
    to = map["to"]?.toString() ?? "";
    conversationType = _get_YIMEnum_ConversationType(map["conversationType"].toString());
    messageType = _get_YIMEnum_MessageType(map["messageType"].toString());
    messageState = _get_YIMEnum_MessageState(map["messageState"].toString());
    time = DateTime.fromMillisecondsSinceEpoch(double.parse(map["time"]?.toString() ?? "0").toInt());
    localExt = map["localExt"]?.toString() ?? "";
    isRevoke = (map["isRevoke"]?.toString() ?? "0") == "1";
  }

  String toJson() => _YIMSDK.utils.toJson({
        "id": id,
        "content": Uri.encodeComponent(content),
        "from": from,
        "to": to,
        "conversationType": _to_YIMEnum_ConversationType(conversationType),
        "messageType": _to_YIMEnum_MessageType(messageType),
        "messageState": _to_YIMEnum_MessageState(messageState),
        "time": time.millisecondsSinceEpoch.toString(),
        "localExt": localExt,
        "isRevoke": isRevoke ? 1 : 0,
      });

  @override
  bool operator ==(Object other) => identical(this, other) || other is YIMMessage && id == other.id;

  @override
  int get hashCode => id.hashCode;
}

class _YIMBroadcastMessage {
  _YIMBroadcastMessage();

  late String id;
  late String from;
  late String content;
  late String time;

  _YIMBroadcastMessage.fromJson(Map<String, dynamic> map) {
    id = map["id"]?.toString() ?? "";
    from = map["from"]?.toString() ?? "";
    content = map["content"]?.toString() ?? "";
    time = map["time"]?.toString() ?? "";
  }

  String toJson() => _YIMSDK.utils.toJson({
        "id": id,
        "from": from,
        "content": content,
        "time": time,
      });
}

class _YIMNotificationMessage {
  _YIMNotificationMessage();

  late String id;
  late String from;
  late String content;
  late String time;

  _YIMNotificationMessage.fromJson(Map<String, dynamic> map) {
    id = map["id"]?.toString() ?? "";
    from = map["from"]?.toString() ?? "";
    content = map["content"]?.toString() ?? "";
    time = map["time"]?.toString() ?? "";
  }

  String toJson() => _YIMSDK.utils.toJson({
        "id": id,
        "from": from,
        "content": content,
        "time": time,
      });
}

class YIMRevokeMessage {
  YIMRevokeMessage();

  late String messageID;
  late String conversationID;
  late YIMEnum_ConversationType conversationType;

  YIMRevokeMessage.fromJson(Map<String, dynamic> map) {
    messageID = map["messageID"]?.toString() ?? "";
    conversationID = map["conversationID"]?.toString() ?? "";
    conversationType = _get_YIMEnum_ConversationType(map["conversationType"].toString());
  }

  String toJson() => _YIMSDK.utils.toJson({
        "messageID": messageID,
        "conversationID": conversationID,
        "conversationType": _to_YIMEnum_ConversationType(conversationType),
      });
}

class YIMConversation {
  YIMConversation();

  int unRead = 0;
  YIMMessage? lastMessage;

  YIMConversation.fromJson(Map<String, dynamic> map) {
    unRead = double.parse(map["unRead"]?.toString() ?? "0").toInt();
    lastMessage = map["lastMessage"] == null ? null : YIMMessage.fromJson(map["lastMessage"] as Map<String, dynamic>);
  }

  String toJson() => _YIMSDK.utils.toJson({
        "unRead": unRead,
        "lastMessage": lastMessage,
      });
}

class _YIMTeam {
  _YIMTeam();

  String id = "";
  String ext = "";

  _YIMTeam.fromJson(Map<String, dynamic> map) {
    id = map["id"]?.toString() ?? "";
    ext = map["ext"]?.toString() ?? "";
  }

  String toJson() => _YIMSDK.utils.toJson({
        "id": id,
        "ext": ext,
      });
}

class _YIMUser {
  _YIMUser();

  String name = "";
  String icon = "";

  _YIMUser.fromJson(Map<String, dynamic> map) {
    name = map["name"]?.toString() ?? "";
    icon = map["icon"]?.toString() ?? "";
  }

  String toJson() => _YIMSDK.utils.toJson({
        "name": name,
        "icon": icon,
      });
}

==> flutter_yim-1.0.6.tar.gz: lib/model/YIMModel.dart <==
part of YIM;

class _YIMSDK {
  static YIMOption? option;
  static String? currentUser;
  static final db = _YIMDB();
  static final server = _YIMServer();
  static final utils = _YIMUtils();
  static final config = _YIMConfig();
}

class YIMOption {
  YIMOption({required this.appKey});

  String appKey;
}

class _YIMResult<T> {
  _YIMResult({required this.code, required this.msg});

  T code;
  String msg;
}

/**
 * 消息体
 */
class YIMMessage {
  YIMMessage();

  String id = "";
  String content = "";
  String from = "";
  String to = "";
  late YIMEnum_ConversationType conversationType;
  late YIMEnum_MessageType messageType;
  late YIMEnum_MessageState messageState;
  late DateTime time;
  String localExt = "";
  bool isRevoke = false;

  YIMMessage.fromJson(Map<String, dynamic> map) {
    id = map["id"]?.toString() ?? "";
    content = Uri.decodeComponent(map["content"]?.toString() ?? "");
    from = map["from"]?.toString() ?? "";
    to = map["to"]?.toString() ?? "";
    conversationType = YIMEnum_ConversationType.from(map["conversationType"].toString());
    messageType = YIMEnum_MessageType.from(map["messageType"].toString());
    messageState = YIMEnum_MessageState.from(map["messageState"].toString());
    time = DateTime.fromMillisecondsSinceEpoch(double.parse(map["time"]?.toString() ?? "0").toInt());
    localExt = map["localExt"]?.toString() ?? "";
    isRevoke = (map["isRevoke"]?.toString() ?? "0") == "1";
  }

  String toJson() => _YIMSDK.utils.toJson({
        "id": id,
        "content": Uri.encodeComponent(content),
        "from": from,
        "to": to,
        "conversationType": conversationType.rawValue,
        "messageType": messageType.rawValue,
        "messageState": messageState.rawValue,
        "time": time.millisecondsSinceEpoch.toString(),
        "localExt": localExt,
        "isRevoke": isRevoke ? 1 : 0,
      });
}

class _YIMBroadcastMessage {
  _YIMBroadcastMessage();

  late String id;
  late String from;
  late String content;
  late String time;

  _YIMBroadcastMessage.fromJson(Map<String, dynamic> map) {
    id = map["id"]?.toString() ?? "";
    from = map["from"]?.toString() ?? "";
    content = map["content"]?.toString() ?? "";
    time = map["time"]?.toString() ?? "";
  }

  String toJson() => _YIMSDK.utils.toJson({
        "id": id,
        "from": from,
        "content": content,
        "time": time,
      });
}

class _YIMNotificationMessage {
  _YIMNotificationMessage();

  late String id;
  late String from;
  late String content;
  late String time;

  _YIMNotificationMessage.fromJson(Map<String, dynamic> map) {
    id = map["id"]?.toString() ?? "";
    from = map["from"]?.toString() ?? "";
    content = map["content"]?.toString() ?? "";
    time = map["time"]?.toString() ?? "";
  }

  String toJson() => _YIMSDK.utils.toJson({
        "id": id,
        "from": from,
        "content": content,
        "time": time,
      });
}

class YIMRevokeMessage {
  YIMRevokeMessage();

  late String messageID;
  late String conversationID;
  late YIMEnum_ConversationType conversationType;

  YIMRevokeMessage.fromJson(Map<String, dynamic> map) {
    messageID = map["messageID"]?.toString() ?? "";
    conversationID = map["conversationID"]?.toString() ?? "";
    conversationType = YIMEnum_ConversationType.from(map["conversationType"].toString());
  }

  String toJson() => _YIMSDK.utils.toJson({
        "messageID": messageID,
        "conversationID": conversationID,
        "conversationType": conversationType.rawValue,
      });
}

class YIMConversation {
  YIMConversation();

  int unRead = 0;
  YIMMessage? lastMessage;

  YIMConversation.fromJson(Map<String, dynamic> map) {
    unRead = double.parse(map["unRead"]?.toString() ?? "0").toInt();
    lastMessage = map["lastMessage"] == null ? null : YIMMessage.fromJson(map["lastMessage"] as Map<String, dynamic>);
  }

  String toJson() => _YIMSDK.utils.toJson({
        "unRead": unRead,
        "lastMessage": lastMessage,
      });
}

class _YIMTeam {
  _YIMTeam();

  String id = "";
  String ext = "";

  _YIMTeam.fromJson(Map<String, dynamic> map) {
    id = map["id"]?.toString() ?? "";
    ext = map["ext"]?.toString() ?? "";
  }

  String toJson() => _YIMSDK.utils.toJson({
        "id": id,
        "ext": ext,
      });
}

class _YIMUser {
  _YIMUser();

  String name = "";
  String icon = "";

  _YIMUser.fromJson(Map<String, dynamic> map) {
    name = map["name"]?.toString() ?? "";
    icon = map["icon"]?.toString() ?? "";
  }

  String toJson() => _YIMSDK.utils.toJson({
        "name": name,
        "icon": icon,
      });
}
